pub enum MessageContent {
Broadcast(Message),
Agreement(Message),
}Expand description
A message about a particular proposer’s contribution.
Variants
Broadcast(Message)
A wrapped message for the broadcast instance, to deliver the proposed value.
Agreement(Message)
A wrapped message for the agreement instance, to decide on whether to accept the value.