pub enum AckFault {
ValueCount,
MissingPart,
DecryptValue,
DeserializeValue,
ValueCommitment,
}Expand description
An error in an Ack message sent by a faulty node.
Variants
ValueCount
The number of values differs from the number of nodes.
MissingPart
No corresponding Part received.
DecryptValue
Value decryption failed.
DeserializeValue
Value deserialization failed.
ValueCommitment
Value doesn’t match the commitment.