Part

Struct Part 

pub struct Part(/* private fields */);
A submission by a validator for the key generation. It must to be sent to all participating nodes and handled by all of them, including the one that produced it.

The message contains a commitment to a bivariate polynomial, and for each node, an encrypted row of values. If this message receives enough Acks, it will be used as summand to produce the the key set in the end.