Module transaction_queue

Module transaction_queue 

An interface for a transaction queue

Traits

TransactionQueue
An interface to the transaction queue. A transaction queue is a structural part of QueueingHoneyBadger that manages enqueueing of transactions for a future batch and dequeueing of transactions to become part of a current batch.