pub type Step<N> = Step<Message<N>, SubsetOutput<N>, N, FaultKind>;Expand description
A Subset step, possibly containing several outputs.
Aliased Type
pub struct Step<N> {
pub output: Vec<SubsetOutput<N>>,
pub fault_log: FaultLog<N, FaultKind>,
pub messages: Vec<TargetedMessage<Message<N>, N>>,
}Fields
output: Vec<SubsetOutput<N>>The algorithm’s output, after consensus has been reached. This is guaranteed to be the same in all nodes.
fault_log: FaultLog<N, FaultKind>A list of nodes that are not following consensus, together with information about the detected misbehavior.
messages: Vec<TargetedMessage<Message<N>, N>>A list of messages that must be sent to other nodes. Each entry contains a message and a
Target.