pub type Step<N> = CpStep<ThresholdDecrypt<N>>;Expand description
A ThresholdDecrypt step. It will contain at most one output.
Aliased Type
pub struct Step<N> {
pub output: Vec<<ThresholdDecrypt<N> as ConsensusProtocol>::Output>,
pub fault_log: FaultLog<<ThresholdDecrypt<N> as ConsensusProtocol>::NodeId, <ThresholdDecrypt<N> as ConsensusProtocol>::FaultKind>,
pub messages: Vec<TargetedMessage<<ThresholdDecrypt<N> as ConsensusProtocol>::Message, <ThresholdDecrypt<N> as ConsensusProtocol>::NodeId>>,
}Fields
output: Vec<<ThresholdDecrypt<N> as ConsensusProtocol>::Output>The algorithm’s output, after consensus has been reached. This is guaranteed to be the same in all nodes.
fault_log: FaultLog<<ThresholdDecrypt<N> as ConsensusProtocol>::NodeId, <ThresholdDecrypt<N> as ConsensusProtocol>::FaultKind>A list of nodes that are not following consensus, together with information about the detected misbehavior.
messages: Vec<TargetedMessage<<ThresholdDecrypt<N> as ConsensusProtocol>::Message, <ThresholdDecrypt<N> as ConsensusProtocol>::NodeId>>A list of messages that must be sent to other nodes. Each entry contains a message and a
Target.